@@ -1,5 +1,8 @@
 
 from powerml import PowerML
+import logging
+
+logger = logging.getLogger(__name__)
 
 
 class PowerMLTopicModel:
@@ -38,7 +41,7 @@ Extract the relevant topics from the above message:
         new_model = self.model.fit(
             [example_string], model="text-davinci-003")
 
-        print("Got new model", new_model)
+        logger.debug("Got new model: " + new_model["model_name"])
         # Note: model_name is also stored in the PowerML class.
         # This step is no longer strictly necessary unless multiple models are
         # being used or you wish to explicitly switch between models.
